## Welcome to Hub20 

Hub20 is a very-early stage open source, self-hosted online payment
solution that can be considered as the Ethereum equivalent of
[BTCPayServer](https://btcpayserver.org) payment gateway, allowing
users to collect payments in Ethereum and any ERC20 token.

Hub20 also provides integration with [Raiden](https://raiden.network),
so that if you have a node running you should be able to accept and
send payments of ERC20 tokens with near-zero fees.

The possiblity of having low-fee payments, irreversibility of
transactions and the usage of stablecoins such as
[DAI](https://makerdao.com) make hub20 a very compelling offer for
anyone that wants to receive payments online.

### More than a payment gateway

Hub20 also allows users *sending* their tokens to either other users
of the hub as well as to any ethereum address, effectively turning any
deployment of a hub20 server into an exclusive Paypal/Venmo/cryptobank
for its users.

This works because hub20 offers the possibility of using custodial
wallets for managing its funds. While this is not ideal for large
deployments such as companies and crypto exchanges, for a self-hosted
service this is more acceptable because the node operator is the one
effectively controlling the wallets and therefore its keys.

This also opens the possibility for, e.g, enthusiasts to set up a
hub20 node for their non-technical friends and family (i.e, people
that are within their circle of trust) so that they can have an easy
way to do transactions in cryptocurrency without ever having to deal
with anything that hinders adoption: nothing to learn about wallets,
no access to exchanges needed, no KYC, etc.

